<?php 

include('header.php');
require('model/UserTypes.php');
require('model/AddUser.php');


$msg_alert = "";


$addUser = new AddUser($pdo);

// Create an instance of UserTypes
$userTypes = new UserTypes($pdo);

// Get all user types
$userTypesList = $userTypes->getAllUserTypes();

// Create the mapping array
$userTypesMap = [];
foreach ($userTypesList as $userType) {
    $userTypesMap[$userType['name']] = $userType['value'];
}

if (isset($_POST['deleteUser'])) {
    $userId = $_POST['userId'];
    if ($addUser->deleteUser($userId)) {
        $msg_alert = '<div class="alert alert-success" role="alert"><strong>Success - </strong> User deleted successfully!</div>';
        echo "<script> setTimeout(function() { window.location.href = 'manage-users'; }, 3000); </script>"; // Redirects after 2 seconds
    } else {
        $msg_alert = '<div class="alert alert-danger" role="alert"><strong>Error - </strong> Error deleting user.</div>';
    }
}

// Handle edit user
if (isset($_POST['editUser'])) {
    $userId = $_POST['userId'];
    $userName = $_POST['userName'];
    $email = $_POST['email'];
    $type = $_POST['type'];

    if ($addUser->updateUser($userId, $userName, $email, $type)) {
        $msg_alert = '<div class="alert alert-success" role="alert"><strong>Success - </strong> User updated successfully!</div>';
        echo "<script> setTimeout(function() { window.location.href = 'manage-users'; }, 3000); </script>";
    } else {
        $msg_alert = '<div class="alert alert-danger" role="alert"><strong>Error - </strong> Error updating user.</div>';
    }
}

$users = $addUser->getUsers();


?>

<!-- [ Main Content ] start -->
<section class="pcoded-main-container">
    <div class="pcoded-content">
        <!-- [ breadcrumb ] start -->
        <div class="page-header">
            <div class="page-block">
                <div class="row align-items-center">
                    <div class="col-md-12">
                        <div class="page-header-title">
                            <h5 class="m-b-10">Location</h5>
                        </div>
                        <ul class="breadcrumb">
                            <li class="breadcrumb-item"><a href="index"><i class="feather icon-home"></i></a></li>
                            <li class="breadcrumb-item"><a href="#!">User Management</a></li>
                            <li class="breadcrumb-item"><a href="manage-users">Manage Users</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
        <!-- [ breadcrumb ] end -->
        <!-- [ Main Content ] start -->
        <div class="row">
            <!-- [ form-element ] start -->
            <div class="col-sm-12">
                <form method="post">
                <div class="card">
                    <div class="card-header">
                        <h5>Users List</h5>
                    </div>
                    <div class="card-body">
                      <?php echo isset($msg_alert) ? $msg_alert : ''; ?>
                        <div class="row">
                            <div class="table-responsive">
                            <table class="table table-striped table-hover table-sm">
                                <thead class="text-center">
                                    <tr>
                                        <th>ID</th>
                                        <th>Name</th>
                                        <th>Email</th>
                                        <th>Type</th>
                                        <th>Created</th>
                                        <th>Action</th>
                                    </tr>
                                </thead>
                                <tbody class="text-center">
                                    <?php if ($users): ?>
                                        <?php foreach ($users as $user): ?>
                                            <tr>
                                                <td><?php echo htmlspecialchars($user['id']); ?></td>
                                                <td><?php echo htmlspecialchars($user['name']); ?></td>
                                                <td><?php echo htmlspecialchars($user['email']); ?></td>
                                                <td><?php echo htmlspecialchars($userTypesMap[$user['type']]); ?></td>
                                                <td><?php echo htmlspecialchars($user['created']); ?></td>
                                                <td>
                                                    <form method="post" style="display:inline;">
                                                        <input type="hidden" name="userId" value="<?php echo $user['id']; ?>">
                                                        <button type="submit" name="deleteUser" class="btn btn-danger rounded-pill delete-user-btn">Delete User</button>
                                                    </form>
                                                    <button type="button" class="btn btn-primary rounded-pill edit-user-btn" 
                                                        data-id="<?php echo $user['id']; ?>" 
                                                        data-name="<?php echo $user['name']; ?>" 
                                                        data-email="<?php echo $user['email']; ?>" 
                                                        data-type="<?php echo $user['type']; ?>">Edit User</button>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php else: ?>
                                        <tr>
                                            <td class="text-center" colspan="6">No users found.</td>
                                        </tr>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                        </div>
                    </div>
                </div>
                </form>
            </div>
            <!-- [ form-element ] end -->
        </div>
        <!-- [ Main Content ] end -->

    </div>
</section>
<!-- [ Main Content ] end -->

<!-- Edit User Modal -->
    <div class="modal fade" id="editUserModal" tabindex="-1" aria-labelledby="editUserModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <form method="post">
                    <div class="modal-header">
                        <h5 class="modal-title" id="editUserModalLabel">Edit User</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" id="editUserId" name="userId">
                        <div class="form-group">
                            <label for="editUserName">User Name</label>
                            <input type="text" class="form-control" id="editUserName" name="userName" required>
                        </div>
                        <div class="form-group">
                            <label for="editEmail">Email</label>
                            <input type="email" class="form-control" id="editEmail" name="email" required>
                        </div>
                        <div class="form-group">
                            <label for="editType">User Type</label>
                            <select class="form-control" id="editType" name="type">
                                <?php foreach ($userTypesList as $userType): ?>
                                    <option value="<?php echo $userType['name']; ?>"><?php echo $userType['value']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                        <button type="submit" name="editUser" class="btn btn-primary">Save changes</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

<?php include('footer.php'); ?>

<script type="text/javascript">

    $(document).ready(function() {
        $('.delete-user-btn').on('click', function(e) {
            var form = $(this).closest('form');
            if (confirm("Are you sure you want to delete this user?")) {
                form.submit();
            }else{
                e.preventDefault();
            }
        });
        
        $('.edit-user-btn').on('click', function() {
            var userId = $(this).data('id');
            var userName = $(this).data('name');
            var email = $(this).data('email');
            var type = $(this).data('type');
            
            $('#editUserId').val(userId);
            $('#editUserName').val(userName);
            $('#editEmail').val(email);
            $('#editType').val(type);
            
            $('#editUserModal').modal('show');
        });
        
    });
    
    </script>
